#
# spec file
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global flavor doc%{nil}

%global srcname ginac

%if "%{flavor}" == "doc"
%bcond_without doc
%define pkg_suffix -doc
%endif

%if "%{flavor}" == ""
%bcond_with doc
%endif

# Latex fails on Leap/SLE 15.x
%if 0%{?suse_version} < 1550
%bcond_with    apiref_pdf
%else
%bcond_without apiref_pdf
%endif

%define library_version 11
Name:           %{srcname}%{?pkg_suffix}
Version:        1.8.7
Release:        1.7
Summary:        C++ library for symbolic calculations
License:        GPL-2.0-only
URL:            https://www.ginac.de/
Source0:        https://www.ginac.de/%{srcname}-%{version}.tar.bz2
# PATCH-FIX-UPSTREAM ginac-fix-makeindex.patch badshah400@gmail.com -- Fix input file path when running makeindex which does not like absolute paths
Patch0:         ginac-fix-makeindex.patch
# PATCH-FIX-UPSTREAM ginac-cmake-install-doc.patch badshah400@gmail.com -- Install man and other documentation files when cmake is used for building
Patch1:         ginac-cmake-install-doc.patch
BuildRequires:  bison
BuildRequires:  cln-devel
BuildRequires:  cmake
BuildRequires:  fdupes
BuildRequires:  flex
BuildRequires:  gcc-c++
BuildRequires:  gmp-devel
BuildRequires:  makeinfo
BuildRequires:  pkgconfig
BuildRequires:  python3-base
BuildRequires:  readline-devel
# SECTION Requirements for building documentation
%if %{with doc}
#!BuildIgnore:  texlive-tex4ht
BuildRequires:  doxygen
BuildRequires:  graphviz
BuildRequires:  graphviz-gnome
BuildRequires:  texinfo
BuildRequires:  texlive-dvips
BuildRequires:  texlive-latex
BuildRequires:  texlive-pdftex
BuildRequires:  transfig
BuildRequires:  tex(float.sty)
BuildRequires:  tex(newunicodechar.sty)
BuildRequires:  tex(xcolor.sty)
%if %{with apiref_pdf}
BuildRequires:  texlive-courier
BuildRequires:  texlive-helvetic
BuildRequires:  texlive-wasy
BuildRequires:  tex(8r.enc)
BuildRequires:  tex(adjustbox.sty)
BuildRequires:  tex(alphalph.sty)
BuildRequires:  tex(caption.sty)
BuildRequires:  tex(changepage.sty)
BuildRequires:  tex(colortbl.sty)
BuildRequires:  tex(enumitem.sty)
BuildRequires:  tex(etoc.sty)
BuildRequires:  tex(fancyhdr.sty)
BuildRequires:  tex(fancyvrb.sty)
BuildRequires:  tex(hanging.sty)
BuildRequires:  tex(helvet.sty)
BuildRequires:  tex(multirow.sty)
BuildRequires:  tex(natbib.sty)
BuildRequires:  tex(sectsty.sty)
BuildRequires:  tex(stackengine.sty)
BuildRequires:  tex(tabu.sty)
BuildRequires:  tex(tocloft.sty)
BuildRequires:  tex(ulem.sty)
BuildRequires:  tex(wasysym.sty)
%endif
%endif
# /SECTION

%description
GiNaC (which stands for "GiNaC is Not a CAS (Computer Algebra System)") is an
open framework for symbolic computation within the C++ programming language.

%package -n libginac%{library_version}
Summary:        C++ library for symbolic calculations

%description -n libginac%{library_version}
GiNaC (which stands for "GiNaC is Not a CAS (Computer Algebra System)") is an
open framework for symbolic computation within the C++ programming language.

%package devel
Summary:        GiNaC development libraries and header files
Requires:       cln-devel
Requires:       libginac%{library_version} = %{version}
Provides:       lib%{name}-devel = %{version}
Obsoletes:      lib%{name}-devel < %{version}
%if 0%{?suse_version} < 1550
Requires(pre):  %{install_info_prereq}
Requires(preun):%{install_info_prereq}
%endif
Recommends:     ginac-doc-tutorial

%description devel
GiNaC (which stands for "GiNaC is Not a CAS (Computer Algebra System)") is an
open framework for symbolic computation within the C++ programming language.

This package contains the libraries, include files and other resources you
use to develop GiNaC applications.

%if "%{flavor}" == "doc"
%package pdf
Summary:        API documentation for GiNaC in PDF format
BuildArch:      noarch

%description pdf
GiNaC (which stands for "GiNaC is Not a CAS (Computer Algebra System)") is an
open framework for symbolic computation within the C++ programming language.

This package provides the API documentation for GiNaC in PDF format.

%package html
Summary:        API documentation for GiNaC in HTML format
BuildArch:      noarch

%description html
GiNaC (which stands for "GiNaC is Not a CAS (Computer Algebra System)") is an
open framework for symbolic computation within the C++ programming language.

This package provides the API documentation for GiNaC in HTML format.

%package tutorial
Summary:        The GiNaC tutorial in PDF format
BuildArch:      noarch

%description tutorial
GiNaC (which stands for "GiNaC is Not a CAS (Computer Algebra System)") is an
open framework for symbolic computation within the C++ programming language.

This package provides a tutorial file for GiNaC in PDF format.

%endif

%prep
%autosetup -p1 -n %{srcname}-%{version}

# Use dot to generate class diagrams. Otherwise, ghostscript is used
# to convert EPS to PDF, which embeds the current time
sed -i -e '/HAVE_DOT/ s/=.*NO/= YES/' doc/reference/DoxyfilePDF.in
# PNG files rendered with cairo are nonreproducible depending on
# CPU features and architecture
sed -i -e '/DOT_IMAGE_FORMAT/ s/=.*png/= svg/' doc/reference/DoxyfileHTML.in

%build
export LDFLAGS="-Wl,--no-undefined"
%cmake -DCMAKE_SKIP_RPATH:BOOL=ON \
       -DCMAKE_INSTALL_LIBEXECDIR:PATH=%{_libexecdir} \
       -DCMAKE_INSTALL_DOCDIR:PATH=%{_docdir}/%{name}

%if "%{flavor}" == "doc"
# Build just the reference doc for the "doc" flavour
pushd doc/reference
%if %{with apiref_pdf}
%cmake_build pdf_dox
%endif
%cmake_build html_dox
popd
pushd doc/tutorial
%cmake_build pdf_ginac_tutorial
popd
%else
%cmake_build
%endif

%install
%if "%{flavor}" == "doc"
install -d -m 755 %{buildroot}%{_docdir}/%{name}/html
cp -R -t %{buildroot}%{_docdir}/%{name}/html/ %{__builddir}/doc/reference/html_files/*

%if %{with apiref_pdf}
install -m 644 -t %{buildroot}%{_docdir}/%{name}/ %{__builddir}/doc/reference/pdflatex/reference.pdf
%endif
%else
%cmake_install
%endif

find %{buildroot} -type f -name "*.la" -delete -print

%fdupes %{buildroot}%{_docdir}/%{name}/html/

# SECTION Unflavoured Pkg
%if "%{flavor}" == ""
%check
export LD_LIBRARY_PATH=%{buildroot}%{_libdir}
%cmake_build check

%post -n libginac%{library_version} -p /sbin/ldconfig
%postun -n libginac%{library_version} -p /sbin/ldconfig

%if 0%{?suse_version} < 1550
%post devel
%install_info --info-dir=%{_infodir} %{_infodir}/ginac.info.gz
%install_info --info-dir=%{_infodir} %{_infodir}/ginac-examples.info.gz

%preun devel
%install_info_delete  --info-dir=%{_infodir} %{_infodir}/ginac.info.gz
%install_info_delete  --info-dir=%{_infodir} %{_infodir}/ginac-examples.info.gz
%endif

%files -n libginac%{library_version}
%{_libdir}/libginac.so.%{library_version}*

%files devel
%license COPYING
%doc AUTHORS ChangeLog NEWS README
%{_libdir}/*.so
%{_libdir}/pkgconfig/ginac.pc
%{_libdir}/cmake/ginac/
%{_includedir}/ginac/
%{_infodir}/*.info%{?ext_info}

%files
%{_bindir}/ginsh
%{_bindir}/viewgar
%{_libexecdir}/ginac-excompiler
%{_mandir}/man1/ginsh.1%{?ext_man}
%{_mandir}/man1/viewgar.1%{?ext_man}
%endif
# /SECTION

# SECTION doc flavoured pkg
%if "%{flavor}" == "doc"
%if %{with apiref_pdf}
%files pdf
%dir %{_docdir}/%{name}
%doc %{_docdir}/%{name}/reference.pdf
%endif

%files html
%dir %{_docdir}/%{name}
%doc %{_docdir}/%{name}/html/

%files tutorial
%doc %__builddir/doc/tutorial/ginac.pdf
%endif
# /SECTION

%changelog
* Thu Dec 28 2023 jun wang <junguo.wang@suse.com>
- Update to version 1.8.7
  * Fix series expansion of polynomial(x)^n for small and large n.
  * Fix bugs in internal parser from strings.
  * Make ginsh evaluate line-by-line in non-interactive mode.
  * Several build fixes.
  * remove obsolete patch ginac-doc-latex-symbol-error.patch
    becuase it has applied into source code
  * update patch ginac-fix-makeindex.patch because one line
    changed
* Mon Jun 12 2023 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 1.8.6:
  * Fix wrong numeric info on transcendental functions.
  * Fix crash of evaluation of binomial(n, k) with negative
    integer n, k.
- Add ginac-doc-latex-symbol-error.patch: Change a math symbol to
  get pdflatex to build reference.pdf correctly; upstream commit.
* Wed Mar  8 2023 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Make documentation build reproducible:
  * Use SVGs for HTML API reference documentation
  * Use dot to generate PDFs, instead of relying on ghostscript
    to convert EPS to PDF
- Disable PDF API reference on Leap/SLE 15.x, fails to build.
* Wed Jan  4 2023 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update to version 1.8.5:
  * Speed up multivariate polynomial factorization
  * fix it in some rare corner cases where it didn't previously
    terminate.
- Move graphviz build dependency to doc flavor package
* Wed Sep 21 2022 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 1.8.4:
  * Complete the support for sqrfree_parfrac().
  * Add info methods for transcendental functions.
- Move BuildArch: noarch tag to relevant subpackages to calm
  rpmlint down.
- Run fdupes for doc-html package.
* Thu Mar 24 2022 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 1.8.3:
  * series_to_poly() can be used from ginsh.
  * Fix power::to_polynomial() for posint exponents.
  * Fix power::subs() in some special cases.
* Sat Jan  1 2022 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 1.8.2:
  * Fix elusive bug in comparing relational objects.
  * Ensure modular_form_kernel::series() includes an Order term.
* Tue Dec 21 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Explicitly BuildRequire tex(enumitem.sty) and tex(alphalph.sty)
  for doc flavor.
* Mon Aug  9 2021 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 1.8.1:
  * Add method relational::canonical() and improve conversion of
    relational to Boolean (it now works on many simple symbolic
    cases).
  * Improve normalization of negative exponents.
  * Fix indexing multiply referenced objects with ex::operator[].
  * Make functions evalf() their arguments before doing own
    evalf().
  * Fix bugs in H_evalf() and in evaluation of iterated integrals.
  * Several portability improvements and compiler warning fixes.
- New BuildRequires for doc flavour: tex(fancyvrb.sty).
* Thu Oct 15 2020 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 1.8.0
  * New routines for the numerical evaluation of iterated
    integrals like elliptic multiple polylogarithms or iterated
    integrals of modular forms.
  * Stronger normalization methods for expressions with powers.
    Where this is safe, GiNaC now tries replacing various kinds of
    powers in order to find and cancel common subexpressions.
  * Improved CMake build.
- Drop _service file and go back to using full URL for Source.
- Update so version in keeping with upstream.
* Sun Oct 11 2020 Atri Bhattacharya <badshah400@gmail.com>
- Use multibuild to split off documentation building from main
  package, whereby we build only the reference documentation and
  tutorial pdf for the "doc" flavour and the main libraries and
  binaries for the unflavoured pkg.
- Move ginac.pdf from the -devel pkg into separate -doc-tutorial
  package as it requires texinfo and texlive to build, and bloats
  the main pkg BuildRequires; add Recommends: ginac-doc-tutorial
  for ginac-devel.
- BuildRequires: python3-base instead of python3.
* Tue Sep 22 2020 Atri Bhattacharya <badshah400@gmail.com>
- Add _service file to use git version at commit 9b53600 as it
  includes various build related fixes over latest tagged version
  1.7.11.
- Add patches to fix/improve builds when using cmake:
  * ginac-fix-makeindex.patch: Fix input file path when running
    `makeindex` which does not like absolute paths.
  * ginac-cmake-install-doc.patch: Install man and other
    documentation files when cmake is used for building.
- Drop ginac-check-for-python3.patch: incorporated upstream.
- Use cmake for build (Add BuildRequires: cmake and drop libtool).
- Build API documentation in PDF and HTML formats and package as
  part of new %%{name}-doc-pdf and %%{name}-doc-html packages
  respectively (add appropriate BuildRequires).
- Drop Group tags from packages.
* Tue Sep 22 2020 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 1.7.11:
  * Fix elusive bugs in factor() and in expand().
- Changes from version 1.7.10:
  * Fix collect_common_factors() for hidden zero arguments.
  * Fix build on modern systems (C++20 and Python3).
- Changes from version 1.7.9:
  * Fix unarchiving of overloaded functions.
  * Fix MinGW64 build.
* Mon Sep 21 2020 Cristian Rodríguez <crrodriguez@opensuse.org>
- Fail to build if there are undefined symbols in the shared library
* Thu Feb  6 2020 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 1.7.8
  * Fix pseries::evalf(), broken since 1.7.0.
  * Fix a corner-case bug in H_evalf().
- Changes from version 1.7.4 to 1.7.7: See
  %%{_docdir}/ginac-devel/NEWS file.
- Use python3 instead of python(2) for building.
- Add ginac-check-for-python3.patch to check for python3 during
  configure; requires running autoreconf before configure.
- Rename devel file to ginac-devel, instead of libginac-devel,
  according to recommended naming guidelines.
- Build and package API documentation and examples in html format;
  add BuildRequires necessary for this.
- Use Requires(post) and Requires(preun) instead of PreReq.
* Fri Apr  6 2018 dimstar@opensuse.org
- Drop baselibs.conf completely: This was introdcued two years ago
  but in this entire time, nobody cared that the resulting -32bit
  library was not installable due to missing dependencies. So it
  is obvioulsy not used.
* Wed Apr  4 2018 dimstar@opensuse.org
- Drop ginac-devel from baselibs: baselibs was produced in 2016,
  but the deps for it where never in place, which means
  ginac-devel-32bit was never installable, and nobody cared.
  Clearly this -32bit package is not used (for -devel there is
  rarely a need for a -32bit package).
* Sun Mar 11 2018 badshah400@gmail.com
- Update to version 1.7.4:
  * Fix ABI compatibility with 1.7.[0-2] (broken unintentionally
    in 1.7.3).
* Sun Feb  4 2018 jengelh@inai.de
- Remove --with-pic which has no effect with --disable-static.
- Fix the shlib package's RPM groups.
* Sat Feb  3 2018 avindra@opensuse.org
- Update to 1.7.3:
  * Speed up some corner cases of polynomial factorization.
  * Speed up some corner cases of gcd computation.
  * Speed up factorization of pre-factored polynomials.
  * Make matrix::solve() work with hidden (non-normal) zeros.
  * Fix bug in evaluation of real and imaginary parts of powers.
  * Fix some LaTeX output, add new function symbol::get_TeX_name().
- cleanup with spec-cleaner
* Mon Jan 30 2017 badshah400@gmail.com
- Update to version 1.7.2:
  * Fix memory leak in operators returning relationals, introduced
    in 1.7.0.
  * Make macro GINAC_DECLARE_REGISTERED_CLASS() work outside
    namespace GiNaC.
  * Fix some build issues.
- Drop ginac-replace-mktemp-with-mkstemp.patch: incorporated
  upstream.
* Fri Nov 25 2016 badshah400@gmail.com
- Fix baselibs.conf file.
* Mon Nov 21 2016 badshah400@gmail.com
- Add ginac-replace-mktemp-with-mkstemp.patch: Replace unsafe and
  deprecated mktemp by its safe variant mkstemp; patch taken from
  upstream git and fixes an rpmlint warning.
* Mon Nov 21 2016 badshah400@gmail.com
- Update to version 1.7.1:
  * Fix crash in basic::subs(), visible in classes which don't
    override it.
  * Fix convergence failure in Li_projection.
  * Fix cliffor_bar() and clifford_star().
  * Improve performance of clifford_to_lst().
  * Fix compilation issues, reduce compiler warnings.
- Changes from version 1.7.0:
  * Make use of C++11 features:
  - Use new language features 'auto', 'nullptr', 'constexpr',
    range-based for loops, the contextual keyword 'override',
    static 'noexcept' operator, etc.
  - Add initializer list ctors for container<>, lst and nested
    initializer lists ctor for class matrix.
  - Add many rvalue reference overloads for ctors from std
    containers. (Note that whether they really speed up things
    depends on whether evaluation leaves the container unchanged
    or not.)
  - Rvalue reference overloads for ctors from std containers
    made it possible to remove the manual 'discardable' hack and
    std::auto_ptr<T> for good.
  - New dynallocate<T>(args...) helper functions obsolete manual
    allocation on the heap and setting the dynallocated status
    flag.
  - Got rid of C++98ish algorithm features (bind2nd, etc.) and
    replaced them with lambdas.
  * Make add::eval(), mul::eval() more careful so they return an
    evaluated, canonical expression without compromise.
  * Remove 'level' argument of all .eval() methods.
  * Remove 'level' arguments of all .evalf() and .normal()
    methods. They were modeled after the .eval() methods.
  * Make relational::rhs() and lhs() nonvirtual.
  * Add support for power::info(info_flags::real).
  * Add fderivative::derivatives() method.
  * Remove broken info_flags::algebraic.
  * Remove unmaintained support for Cint.
  * Remove unfinished code for hash table-based expairseq.
  * Remove deprecated ex::to_rational(lst) and
    ex::to_polynomial(lst).
  * ginac-excompiler installs in $LIBEXECDIR now, not in $BINDIR.
  * Many minor performance enhancements.
- Changes from previous versions 1.6.3 through 1.6.7: See
  http://www.ginac.de/News.html.
- Add a baselibs.conf file.
- Drop ginac-return-in-nonvoid.patch, no longer required.
* Mon Dec 12 2011 pgajdos@suse.com
- added libtool into explicit build requires
* Sat Nov 19 2011 werner.ho@gmx.de
- new version 1.6.2
* Sun Oct 23 2011 arun@gmx.de
- added patch (git commit 265e5f9537)
* Tue May 24 2011 pgajdos@novell.com
- updated to 1.6.0
* Thu Aug 19 2010 pgajdos@suse.cz
- updated to 1.5.7
  * upstreamed gcc45.patch
* Tue Feb 23 2010 pgajdos@suse.cz
- fixed build with gcc 4.5
  * gcc45.patch
* Mon Feb  1 2010 pgajdos@suse.cz
- updated to 1.5.6
- disable rpath
- library_version variable in spec file
* Thu Jun 26 2008 crrodriguez@suse.de
- run make check
* Tue Oct 30 2007 crrodriguez@suse.de
- first version for the OBS
